@@ -28,7 +28,7 @@ class _NoOpPBar(object):
         pass
 
 
-def get_progress_bar(display, total):
+def get_progress_bar(display, total, **kwargs):
     """Get a progress bar interface with given properties
 
     If the tqdm library is not installed, this will always return a "progress
@@ -38,6 +38,7 @@ def get_progress_bar(display, total):
         display (bool or str): Should the bar actually show the progress? Or a
                                string to indicate which tqdm bar to use.
         total (int): The total size of the progress bar.
+        kwargs (dict): Optional keyword arguments to be passed to the tqdm call.
 
     """
     if display:
@@ -49,8 +50,8 @@ def get_progress_bar(display, total):
             return _NoOpPBar()
         else:
             if display is True:
-                return tqdm.tqdm(total=total)
+                return tqdm.tqdm(total=total, **kwargs)
             else:
-                return getattr(tqdm, "tqdm_" + display)(total=total)
+                return getattr(tqdm, "tqdm_" + display)(total=total, **kwargs)
 
     return _NoOpPBar()
