@@ -3,7 +3,7 @@ import time
 import re
 
 # from datetime import datetime
-from pathlib import Path
+from pathlib import Path, PurePath
 
 try:
     import xml.etree.cElementTree as ET
@@ -11,20 +11,25 @@ except ImportError:
     import xml.etree.ElementTree as ET
 import numpy as np
 
-try:
-    from orsopy.fileio import load_orso
-except Exception:
-    # orsopy has issues on Python 3.10
-    def load_orso(f):
-        raise ImportError(
-            "Problem importing orsopy with this Python installation"
-        )
-
-
 from refnx.dataset import Data1D
 from refnx._lib import possibly_open_file
 
 
+def load_orso(f):
+    from orsopy.fileio import load_orso as _load_orso
+    from orsopy.fileio import load_nexus
+
+    try:
+        return _load_orso(f)
+    except Exception:
+        pass
+    try:
+        v = load_nexus(f)
+        return v
+    except Exception:
+        pass
+
+
 _template_ref_xml = """<?xml version="1.0"?>
 <REFroot xmlns="">
 <REFentry time="$time">
@@ -83,13 +88,10 @@ class ReflectDataset(Data1D):
         if np.all(self._mask):
             msk = None
 
-        d = {"filename": str(self.filename), "msk": msk, "data": self.data}
         if self.filename is not None:
-            return "ReflectDataset(data={filename!r}," " mask={msk!r})".format(
-                **d
-            )
+            return f"ReflectDataset(data={str(self.filename)!r}, mask={msk!r})"
         else:
-            return "ReflectDataset(data={data!r}," " mask={msk!r})".format(**d)
+            return f"ReflectDataset(data={self.data!r}, mask={msk!r})"
 
     def save_xml(self, f, start_time=0):
         """
@@ -157,6 +159,12 @@ class ReflectDataset(Data1D):
             drvals = [float(val) for val in drtext if len(val)]
             dqvals = [float(val) for val in dqtext if len(val)]
 
+            if isinstance(fname, PurePath):
+                # use a PurePath, not a system specific path type
+                # because Posix systems can't deal with WindowsPath
+                # and vice versa. This becomes an issue when pickling.
+                fname = PurePath(fname)
+
             self.filename = fname
             self.name = Path(fname).stem
             self.data = (qvals, rvals, drvals, dqvals)
@@ -197,17 +205,45 @@ class OrsoDataset(Data1D):
             else:
                 fname = ""
         else:
-            fname = f
+            # string-like??
+            fname = str(f)
 
-        with possibly_open_file(f, "r") as g:
+        mode = "r"
+        if fname.endswith(".orb"):
+            mode = "rb"
+
+        with possibly_open_file(f, mode) as g:
             self.orso = load_orso(g)
+            header = self.orso[0].info
 
         _data = self.orso[0].data[:, :4].T
+
+        # figure out if data was in 1/nm or 1/angstrom
+        # internally refnx uses reciprocal angstrom
+        q_units = header.columns[0].unit.lower()
+        if q_units == "1/nm":
+            # need to divide q by 10
+            _data[0] /= 10.0
+
+            if _data.shape[0] > 3:
+                _data[3] /= 10.0
+
         # ORSO files save resolution information as SD,
         # internally refnx uses FWHM
-        if _data.shape[1] > 3:
+        if _data.shape[0] > 3:
             _data[3] *= 2.3548
 
         self.data = _data
         self.filename = fname
         self.name = Path(fname).stem
+
+    def refresh(self):
+        """
+        Refreshes a previously loaded dataset.
+
+        """
+        # OrsoDataset needs to carry its own implementation
+        # opening a binary file needs to be done with correct mode
+        # vs opening a text file.
+        if self.filename is not None:
+            self.load(self.filename)
