@@ -2,6 +2,8 @@ import os
 
 from refnx.reflect.reflect_model import (
     ReflectModel,
+    ReflectModelTL,
+    PolarisedReflectModel,
     reflectivity,
     MixedReflectModel,
     FresnelTransform,
@@ -9,16 +11,20 @@ from refnx.reflect.reflect_model import (
     use_reflect_backend,
     available_backends,
     abeles,
+    SpinChannel,
 )
 from refnx.reflect.structure import (
     Structure,
     SLD,
     Slab,
+    MagneticSlab,
     Component,
     sld_profile,
     Stack,
     MaterialSLD,
     MixedSlab,
+    create_occupancy,
+    possibly_create_scatterer,
 )
 from refnx.reflect.interface import (
     Erf,
@@ -30,7 +36,8 @@ from refnx.reflect.interface import (
     Step,
 )
 from refnx.reflect.spline import Spline
-from refnx.reflect._lipid import LipidLeaflet
+from refnx.reflect._lipid import LipidLeaflet, LipidLeafletGuest
+from refnx.reflect._functional_form import FunctionalForm
 from refnx._lib._testutils import PytestTester
 from refnx.reflect._app import gui, main
 
@@ -42,6 +49,14 @@ from refnx.reflect._app import gui, main
 # OMP
 os.environ.setdefault("KMP_DUPLICATE_LIB_OK", "True")
 
+try:
+    import numba
+
+    # set the threading layer before any parallel target compilation
+    numba.config.THREADING_LAYER = "forksafe"
+except ImportError:
+    pass
+
 try:
     from refnx.reflect._interactive_modeller import Motofit
 except ImportError:
